import numpy as np
import matplotlib.pyplot as plt

from skimage import io
from skimage.color import rgb2gray
from skimage.feature import ORB, match_descriptors, plot_matches

pano_imgs = io.ImageCollection('./JDW_9*')

# Make grayscale versions of the three color images in pano_imgs
# named pano0, pano1, and pano2
p0 = rgb2gray(pano_imgs[0])
p1 = rgb2gray(pano_imgs[1])
p2 = rgb2gray(pano_imgs[2])


# Initialize ORB
orb = ORB(n_keypoints=800, fast_threshold=0.05)

# Detect keypoints in pano0
orb.detect_and_extract(p0)
keypoints0 = orb.keypoints
descriptors0 = orb.descriptors

# Detect keypoints in pano1 and pano2
orb.detect_and_extract(p1)
keypoints1 = orb.keypoints
descriptors1 = orb.descriptors

orb.detect_and_extract(p2)
keypoints2 = orb.keypoints
descriptors2 = orb.descriptors


# Match descriptors between left/right images and the center
matches01 = match_descriptors(descriptors0, descriptors1, cross_check=True)
matches12 = match_descriptors(descriptors1, descriptors2, cross_check=True)

fig, ax = plt.subplots(1, 1, figsize=(12, 12))
# Best match subset for pano0 -> pano1
plot_matches(ax, p0, p1, keypoints0, keypoints1, matches01)
ax.axis('off');
plt.show()
